@@ -1,7 +1,18 @@
 from enum import Enum
-from typing import Any
+from typing import Any, TypeVar
 from pydantic import BaseModel as BM
 
+T = TypeVar('T')
+
+class GetResponseHandlerException(Exception):
+    def __init__(self, response:dict, responses_handlers:list):
+        self.response = response
+        self.responses_handlers = responses_handlers
+
+    def __str__(self) -> str:
+        return (f'It is not possible to process the response with handlers: {self.responses_handlers}\n' +
+                f'response: {self.response}')
+
 class BaseMethod:
     def __init__(self, vk):
         self.vk = vk
@@ -12,6 +23,20 @@ class BaseMethod:
         except: pass
         return await self.vk.call_method(method, **params)
 
+class Int:
+    @classmethod
+    def parse_obj(cls, obj:int):
+        return int(obj)
+
+class Bool:
+    @classmethod
+    def parse_obj(cls, obj:bool):
+        return bool(obj)
+
+class Str:
+    @classmethod
+    def parse_obj(cls, obj:str):
+        return str(obj)
 
 class BaseList(BM):
     __root__:list
